Skip to contentSkip to conversation

lguest: use ioremap_cache, not ioremap

PATCH New Rusty Russell 1 participant 1 message May 16, 2008

lore
Share & tools
lore
#0 lore raw

PATCH 1/1 lguest: use ioremap_cache, not ioremap

Thanks to Jon Corbet & LWN. Only took me a day to join the dots.

Host->Guest netcat before (with unnecessily large receive buffers):
1073741824 bytes (1.1 GB) copied, 24.7528 seconds, 43.4 MB/s

After:
1073741824 bytes (1.1 GB) copied, 17.6369 seconds, 60.9 MB/s

---
 drivers/lguest/lguest_device.c |    2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
drivers/lguest/lguest_device.c +1 -1
diff -r f0417cb4869e drivers/lguest/lguest_device.c
@@ -27,7 +27,7 @@ static unsigned int dev_index;
  * __iomem to quieten sparse. */
 static inline void *lguest_map(unsigned long phys_addr, unsigned long pages)
 {
-	return (__force void *)ioremap(phys_addr, PAGE_SIZE*pages);
+	return (__force void *)ioremap_cache(phys_addr, PAGE_SIZE*pages);
 }
 
 static inline void lguest_unmap(void *addr)